==> BOP-1.8.9-3.0.x.tar.gz: biomesoplenty/README.md <==
<p align="center"><img src="http://i.imgur.com/wdIIbNr.png"></p>

**Biomes O' Plenty** is a **Minecraft mod** that adds **over 50 new biomes** to the overworld and Nether. From coral reefs to bamboo forests, all of our biomes are decorated with a slew of **new plants, trees, flowers, and more!**

-----------------

**Note:** To use the mod on a **server**, you must set the **level-type** setting in your server's config file to **BIOMESOP**

Also, if you want to **disable or add certain world generation features** in certain biomes, check out our guide for creating **biome configuration files**: https://github.com/Glitchfiend/BiomesOPlenty/wiki/Configuring-Biomes

-----------------

**Please note that the 1.8.9 version is still in development.  Whilst it may have many bugs fixed compared to 1.7, there will still be some missing features.**
 
 -----------------

 [<img src="http://i.creativecommons.org/l/by-nc-nd/3.0/88x31.png">](http://creativecommons.org/licenses/by-nc-nd/4.0/deed.en_US)

Biomes O' Plenty is licensed under a [Creative Commons Attribution-NonCommercial-NoDerivs 4.0 Unported License](http://creativecommons.org/licenses/by-nc-nd/4.0/deed.en_US).

-----------------

We've partnered with **CreeperHost**, and will be launching an **official Glitchfiend server** soon, with all of our mods installed.  It won't be happening until they're updated to 1.9, but feel free to use this **promo code** when ordering a server of your own!

<p align="center"><img src="http://i.imgur.com/rjmyjrV.png"></p>

==> BOP-1.10.2-5.0.x.tar.gz: biomesoplenty/README.md <==
<p align="center"><img src="http://i.imgur.com/wdIIbNr.png"></p>

**Biomes O' Plenty** is a **Minecraft mod** that adds **over 50 new biomes** to the overworld and Nether. From coral reefs to bamboo forests, all of our biomes are decorated with a slew of **new plants, trees, flowers, and more!**

-----------------

**Note:** To use the mod on a **server**, you must set the **level-type** setting in your server's config file to **BIOMESOP**

Also, if you want to **disable or add certain world generation features** in certain biomes, check out our guide for creating **biome configuration files**: https://github.com/Glitchfiend/BiomesOPlenty/wiki/Configuring-Biomes

-----------------

**Please note that the 1.9 version is still in development.  Whilst it may have many bugs fixed compared to 1.7/1.8.9, there will still be some missing features.**
 
 -----------------

 [<img src="http://i.creativecommons.org/l/by-nc-nd/3.0/88x31.png">](http://creativecommons.org/licenses/by-nc-nd/4.0/deed.en_US)

Biomes O' Plenty is licensed under a [Creative Commons Attribution-NonCommercial-NoDerivs 4.0 Unported License](http://creativecommons.org/licenses/by-nc-nd/4.0/deed.en_US).

-----------------

We've partnered with **CreeperHost**, and will be launching an **official Glitchfiend server** soon, with all of our mods installed.  It won't be happening until they're updated to 1.9, but feel free to use this **promo code** when ordering a server of your own!

<p align="center"><img src="http://i.imgur.com/rjmyjrV.png"></p>
